@@ -23,10 +23,14 @@
 #include <QThread>
 #include <qplatformdefs.h>
 
-#include <memory>
-#include <utime.h>
 #include <zlib.h>
 
+#include <memory>
+
+#if !HAVE_CHRONO_CAST
+#include <utime.h>
+#endif
+
 K_PLUGIN_CLASS_WITH_JSON(LibzipPlugin, "kerfuffle_libzip.json")
 
 template<auto fn>
@@ -276,7 +280,7 @@ bool LibzipPlugin::list()
     return true;
 }
 
-bool LibzipPlugin::addFiles(const QVector<Archive::Entry *> &files,
+bool LibzipPlugin::addFiles(const QList<Archive::Entry *> &files,
                             const Archive::Entry *destination,
                             const CompressionOptions &options,
                             uint numberOfEntriesToAdd)
@@ -572,7 +576,7 @@ bool LibzipPlugin::emitEntryForIndex(zip_t *archive, qlonglong index)
     return true;
 }
 
-bool LibzipPlugin::deleteFiles(const QVector<Archive::Entry *> &files)
+bool LibzipPlugin::deleteFiles(const QList<Archive::Entry *> &files)
 {
     int errcode = 0;
     zip_error_t err;
@@ -702,7 +706,7 @@ bool LibzipPlugin::doKill()
     return false;
 }
 
-bool LibzipPlugin::extractFiles(const QVector<Archive::Entry *> &files, const QString &destinationDirectory, const ExtractionOptions &options)
+bool LibzipPlugin::extractFiles(const QList<Archive::Entry *> &files, const QString &destinationDirectory, const ExtractionOptions &options)
 {
     qCDebug(ARK) << "Extracting files to:" << destinationDirectory;
     const bool extractAll = files.isEmpty();
@@ -801,9 +805,13 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
     // For top-level items, don't restore parent dir mtime.
     const bool restoreParentMtime = (parentDir + QDir::separator() != destDirCorrected);
 
-    time_t parent_mtime;
+    std::filesystem::file_time_type parent_mtime;
+    std::error_code error_code;
     if (restoreParentMtime) {
-        parent_mtime = QFileInfo(parentDir).lastModified().toMSecsSinceEpoch() / 1000;
+        parent_mtime = std::filesystem::last_write_time(QFileInfo(parentDir).filesystemAbsoluteFilePath(), error_code);
+        if (error_code) {
+            qCWarning(ARK) << "Failed to read parent modtime" << error_code.message();
+        }
     }
 
     // Create parent directories for files. For directories create them.
@@ -944,26 +952,42 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
     }
 
     // Set mtime for entry (also access time otherwise it's "uninitilized")
+#if HAVE_CHRONO_CAST
+    const auto time = std::chrono::clock_cast<std::chrono::file_clock>(std::chrono::system_clock::from_time_t(statBuffer.mtime));
+    std::filesystem::last_write_time(QFileInfo(destination).filesystemAbsoluteFilePath(), time, error_code);
+    if (error_code) {
+        qCWarning(ARK) << "Failed to restore mtime:" << destination << error_code.message();
+    }
+#else
     utimbuf times;
     times.actime = statBuffer.mtime;
     times.modtime = statBuffer.mtime;
     if (utime(destination.toUtf8().constData(), &times) != 0) {
         qCWarning(ARK) << "Failed to restore mtime:" << destination;
     }
+#endif
+
+    Q_ASSERT([&] {
+        const auto mtime = QDateTime::fromSecsSinceEpoch(statBuffer.mtime);
+        const auto actualMtime = QFileInfo(destination).fileTime(QFile::FileModificationTime);
+        if (mtime != actualMtime) {
+            qDebug() << "Target mtime:" << mtime << "Actual mtime:" << actualMtime;
+            return false;
+        }
+        return true;
+    }());
 
     if (restoreParentMtime) {
         // Restore mtime for parent dir.
-        times.actime = parent_mtime;
-        times.modtime = parent_mtime;
-        if (utime(parentDir.toUtf8().constData(), &times) != 0) {
-            qCWarning(ARK) << "Failed to restore mtime for parent dir of:" << destination;
+        std::filesystem::last_write_time(QFileInfo(parentDir).filesystemAbsoluteFilePath(), parent_mtime, error_code);
+        if (error_code) {
+            qCWarning(ARK) << "Failed to restore mtime for parent dir of:" << destination << error_code.message();
         }
     }
-
     return true;
 }
 
-bool LibzipPlugin::moveFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options)
+bool LibzipPlugin::moveFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options)
 {
     Q_UNUSED(options)
     int errcode = 0;
@@ -1017,7 +1041,7 @@ bool LibzipPlugin::moveFiles(const QVector<Archive::Entry *> &files, Archive::En
     return true;
 }
 
-bool LibzipPlugin::copyFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options)
+bool LibzipPlugin::copyFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options)
 {
     Q_UNUSED(options)
     int errcode = 0;
